# -*- coding: utf8 -*-
import logging.config
import os

import click
from frigg.config import config, sentry
from frigg.helpers import local_run

from .fetcher import fetcher

logger = logging.getLogger(__name__)


def load_logging_config():
    try:
        logging.config.fileConfig(os.path.join(os.path.dirname(__file__), 'logging.conf'))
    except Exception as e:
        print("There is a problem with the logging config:\n%s" % e)


@click.command()
@click.option('--dispatcher-url', default=None, help='Url to the dispatcher, overrides settings')
@click.option('--dispatcher-token', default=None, help='Token for dispatcher, overrides settings')
def start(**kwargs):
    load_logging_config()

    try:
        print("Starting frigg worker")
        local_run("mkdir -p %s" % config('TMP_DIR'))
        fetcher(**kwargs)
    except Exception as e:
        logger.error(e)
        sentry.captureException()


if __name__ == '__main__':
    start()



# -*- coding: utf8 -*-
import logging
import random
import time

import requests
from frigg.config import config

from .jobs import Build

logger = logging.getLogger(__name__)


def fetcher(dispatcher_url=None, dispatcher_token=None):
    while True:
        task = fetch_task(dispatcher_url, dispatcher_token)
        if task:
            start_build(task)

        time.sleep(5.0 + random.randint(1, 100) / 100)


def start_build(task):
    build = Build(task['id'], task)
    logger.info('Starting %s' % task)
    build.run_tests()


def fetch_task(dispatcher_url, dispatcher_token):
    if dispatcher_url is None:
        dispatcher_url = config('DISPATCHER_FETCH_URL')
    if dispatcher_token is None:
        dispatcher_token = config('DISPATCHER_TOKEN')

    logger.debug('Fetching new job from {}'.format(dispatcher_url))
    response = requests.get(
        dispatcher_url,
        headers={
            'x-frigg-worker-token': dispatcher_token
        }
    )
    return response.json()['job']
